@@ -3,7 +3,7 @@
 import weakref, platform, random, uuid, inspect, imp, os
 import Tkinter, tkFileDialog
 import ttk #@UnresolvedImport
-import core, gui, mpl
+import core, gui, widgets, mpl
 
 if platform.system() == 'Darwin':
     BUTTON_R = '<Button-2>'
@@ -12,11 +12,23 @@ else:
 
 def classname(obj): return repr(obj.__class__).split('.')[-1].split(' ')[0]
 
-def invoke_kitchen():
-    Kitchen(Tkinter.Toplevel()).pack()
+def invoke_kitchen(master=None):
+    if master.__class__ == Tkinter.Tk:
+        Kitchen(master).pack()
+    else:
+        Kitchen(Tkinter.Toplevel(master)).pack()
+def prepare():
+    invoke_kitchen(Tkinter.Tk())
+    
+#class KitchenMenu(gui.Menu):
+#    def __init__(self,master=None,desc=[],cnf={},**kw):
+#        gui.Menu.__init__(self,master,cnf,**kw)
+#        self.add_command(label='Kitchen',command=invoke_kitchen)
+#    def assign(self,component): pass
 
-gui.MenuFactory.DEFAULT_ITEMS.insert(0,['PyLAF', ['Kitchen','command']])
-gui.MenuFactory.DEFAULT_ASSIGNS.append([('pylaf',),0,invoke_kitchen])
+def kw(**kw): return kw
+#gui.DefaultMenu.DEFAULT_ITEMS[0].insert(1, ['Kitchen', KitchenMenu])
+gui.DefaultMenu.DEFAULT_ITEMS[0].insert(1, ['add_command', kw(label='Kitchen',command=invoke_kitchen)])
 
 def iscontain(obj,cls):
     try: bases = inspect.getmro(obj.__class__) # オブジェクトのクラスツリーをタプルで返す
@@ -27,19 +39,6 @@ def iscontain(obj,cls):
     else:
         return False
 
-class Sample(gui.ComponentWithGUI):
-    class Console(gui.Grid):
-        def __init__(self,master=None,cnf={},**kw):
-            gui.Grid.__init__(self,master,cnf,**kw)
-            self.append(gui.Entry(self,name='entry1'),label='Entry1')
-            self.append(gui.Entry(self,name='entry2'),label='Entry2')
-            self.counter = 0
-            self.thread()
-        def thread(self):
-            self.counter = self.counter + 1
-            print 'alive', self.counter
-            self.after(1000,self.thread)
-
 class SimpleDialog(Tkinter.Toplevel): pass
 
 class ComponentChooser(ttk.Frame):
@@ -63,6 +62,7 @@ class ComponentChooser(ttk.Frame):
         for name in os.listdir(dir):
             if name.endswith('.py'):
                 selection.append(name)
+        if len(selection) == 0: return
         self.parse_selection(selection)
     def select_module(self):
         # askopenfilename, askopenfilenames, askdirectory
@@ -95,9 +95,9 @@ class ComponentChooser(ttk.Frame):
             else:
                 m  = imp.load_module(name,*imp.find_module(name))
             self.update_by_module(m)
-        except SyntaxError: print 'Syntax Error'
-        except ImportError: print 'Import Error'
-        except AttributeError: print 'Attribute Error'
+        except SyntaxError: print 'Syntax Error', name
+        except ImportError: print 'Import Error', name
+        except AttributeError: print 'Attribute Error', name
     def made_decision(self):
         tv = self.children['klass']
         id = tv.selection()
@@ -244,7 +244,9 @@ class ComponentTree(ttk.Treeview):
         cc = ComponentChooser(Tkinter.Toplevel(self))
         cc.master.destroy()
         if cc.selection:
-            self.queue.append(cc.selection(parent))
+            item = cc.selection(parent)
+            self.queue.append(item)
+            self.master.newtoplevel(item)
     def newchild(self):
         key = self.myfocus()
         if key == None: return
@@ -252,7 +254,9 @@ class ComponentTree(ttk.Treeview):
         cc = ComponentChooser(Tkinter.Toplevel(self))
         cc.master.destroy()
         if cc.selection:
-            self.queue.append(cc.selection(parent))
+            item = cc.selection(parent)
+            self.queue.append(item)
+            self.master.newtoplevel(item)
     def mydelete(self):
         key = self.myfocus()
         if key == None: return
@@ -264,7 +268,8 @@ class WidgetTree(ttk.Treeview):
     class Menu(Tkinter.Menu):
         def __init__(self,master=None,cnf={},**kw):
             Tkinter.Menu.__init__(self,master,cnf,**kw)
-            self.add_command(label='New Toplevel as Application',command=core.CallWrapper(master.newtoplevel))
+            self.add_command(label='New Toplevel as Console',command=core.CallWrapper(master.newtoplevel))
+            self.add_command(label='New Toplevel as Console',command=core.CallWrapper(master.newidptoplevel))
             self.add_command(label='New Sibling as Embed',command=core.CallWrapper(master.newsibling))
             self.add_command(label='New Child as Embed',command=core.CallWrapper(master.newchild))
             self.add_command(label='Delete',command=core.CallWrapper(master.mydelete))
@@ -329,13 +334,25 @@ class WidgetTree(ttk.Treeview):
         if    len(item) == 0: return ''
         elif  len(item) == 1: return item[0]
         else: return
-    def newtoplevel(self):
+    def newtoplevel(self,component=None):
+        if component == None:
+            component = self.master.focus()
+#        component = self.master.focus()
+        if component == None: return
+        key    = ''
+        parent = self.widgets[key]
+        top    = Tkinter.Toplevel(parent)
+        gui.Console(top,component)
+        item   = self.insert(key,'end',text=classname(top),values=[repr(id(top))])
+        self.widgets[item] = top
+        self.populate(item,top)
+    def newidptoplevel(self):
         component = self.master.focus()
         if component == None: return
         key    = ''
         parent = self.widgets[key]
         top    = Tkinter.Toplevel(parent)
-        gui.Layout.Application(top,component)
+        gui.Console(top,component,sync=False)
         item   = self.insert(key,'end',text=classname(top),values=[repr(id(top))])
         self.widgets[item] = top
         self.populate(item,top)
@@ -793,33 +810,39 @@ class Kitchen(Tkinter.Frame):
         self.linkviewer().activate(terminals)
     def hide_links(self):
         self.linkviewer().deactivate()
-
+    def newtoplevel(self,component=None):
+        self.children['widgettree'].newtoplevel(component)
+        
 if __name__ == '__main__':
     import gui
-    class MyComponent(gui.ComponentWithGUI):
-        class Console(gui.Grid):
+    class MyComponent(core.Component):
+        class Control(gui.Panel):
             def __init__(self,master=None,cnf={},**kw):
-                gui.Grid.__init__(self,master,cnf,**kw)
-                self.append(gui.Entry(self,name='entry1'),label='Entry1')
-        class Menu(gui.MenuFactory):
-            DESC = [['PyLAF', ['Kitchen', 'command']],]
-            def __init__(self,master=None,cnf={},**kw):
-                gui.MenuFactory.__init__(self,master,self.DESC,cnf,**kw)
-            def assign(self,comp):
-                self.children['pylaf'].assign('kitchen',self.invoke_kitchen)
-            def invoke_kitchen(self):
-                tk = self
-                while tk.master: tk = tk.master
-                Kitchen(Tkinter.Toplevel(tk)).pack()
+                gui.Panel.__init__(self,master,cnf,**kw)
+                builder = gui.TableBuilder(self)
+                builder.add(Tkinter.Label,text='Entry1').grid()
+                builder.add(widgets.Entry,name='entry1').grid()
+                #self.append(gui.Entry(self,name='entry1'),label='Entry1')
+        #class Menu(gui.MenuFactory):
+        #    DESC = [['PyLAF', ['Kitchen', 'command']],]
+        #    def __init__(self,master=None,cnf={},**kw):
+        #        gui.MenuFactory.__init__(self,master,self.DESC,cnf,**kw)
+        #    def assign(self,comp):
+        #        self.children['pylaf'].assign('kitchen',self.invoke_kitchen)
+        #    def invoke_kitchen(self):
+        #        tk = self
+        #        while tk.master: tk = tk.master
+        #        Kitchen(Tkinter.Toplevel(tk)).pack()
         def __init__(self,master=None,name=None):
-            gui.ComponentWithGUI.__init__(self,master,name)
+            core.Component.__init__(self,master,name)
             self.entry1 = core.Port(0.)
             self.entry2 = core.Port(0.)
             self.entry3 = core.Port(0.)
             self.entry4 = core.Port(0.)
     
     tk = Tkinter.Tk()
-    basic = gui.Layout.Application(tk,MyComponent(core.Root()),title='basic sample')
+    basic = gui.Console(tk,MyComponent(core.Root()))
+    basic.master.title('basic sample')
     c = basic.comp()
     my   = MyComponent(core.Root(),name='component')
     my1  = MyComponent(c,name='component1')
