@@ -197,6 +197,22 @@ class LabelTable(Tkinter.Frame):
                 else:
                     self.joint[i][j].set_now(value[i][j])
                     
+class Text(Tkinter.Text):
+    def __init__(self,master=None,cnf={},**kw):
+        Tkinter.Text.__init__(self,master,cnf,**kw)
+        self.value = core.Port('').bind(self._forward)
+        self.bind('<KeyPress>',self._backward)
+    def _forward(self):
+        try: self._backward_running
+        except: pass
+        else: return
+        self.delete('0.0',Tkinter.END)
+        self.insert('0.0',self.value.get())
+    def _backward(self,e):
+        self._backward_running = True
+        self.value.set(self.get('0.0',Tkinter.END))
+        del self._backward_running
+        
 class Button(Tkinter.Button):
     '''クリックすると登録したコールバックを起動する。コールバックは通常のTkinter.Buttonと同様にcommand=<method>オプションで指定できる。'''
     def __init__(self,master=None,cnf={},**kw):
